==> vtk6-6.3.0-5-armv7h.pkg.tar.xz: vtk/vtkRearrangeFields.java <==
// java wrapper for vtkRearrangeFields object
//

package vtk;
import vtk.*;

public class vtkRearrangeFields extends vtkDataSetAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int AddOperation_2(int id0,int id1,int id2,int id3);
  public int AddOperation(int id0,int id1,int id2,int id3)
    { return AddOperation_2(id0,id1,id2,id3); }

  private native int AddOperation_3(int id0,String id1,int id2,int id3);
  public int AddOperation(int id0,String id1,int id2,int id3)
    { return AddOperation_3(id0,id1,id2,id3); }

  private native int AddOperation_4(String id0,String id1,String id2,String id3);
  public int AddOperation(String id0,String id1,String id2,String id3)
    { return AddOperation_4(id0,id1,id2,id3); }

  private native int RemoveOperation_5(int id0);
  public int RemoveOperation(int id0)
    { return RemoveOperation_5(id0); }

  private native int RemoveOperation_6(int id0,int id1,int id2,int id3);
  public int RemoveOperation(int id0,int id1,int id2,int id3)
    { return RemoveOperation_6(id0,id1,id2,id3); }

  private native int RemoveOperation_7(int id0,String id1,int id2,int id3);
  public int RemoveOperation(int id0,String id1,int id2,int id3)
    { return RemoveOperation_7(id0,id1,id2,id3); }

  private native int RemoveOperation_8(String id0,String id1,String id2,String id3);
  public int RemoveOperation(String id0,String id1,String id2,String id3)
    { return RemoveOperation_8(id0,id1,id2,id3); }

  private native void RemoveAllOperations_9();
  public void RemoveAllOperations()
    { RemoveAllOperations_9(); }

  public vtkRearrangeFields() { super(); }

  public vtkRearrangeFields(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv7h.pkg.tar.xz: vtk/vtkRearrangeFields.java <==
// java wrapper for vtkRearrangeFields object
//

package vtk;
import vtk.*;

public class vtkRearrangeFields extends vtkDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int AddOperation_2(int id0,int id1,int id2,int id3);
  public int AddOperation(int id0,int id1,int id2,int id3)
    { return AddOperation_2(id0,id1,id2,id3); }

  private native int AddOperation_3(int id0,String id1,int id2,int id3);
  public int AddOperation(int id0,String id1,int id2,int id3)
    { return AddOperation_3(id0,id1,id2,id3); }

  private native int AddOperation_4(String id0,String id1,String id2,String id3);
  public int AddOperation(String id0,String id1,String id2,String id3)
    { return AddOperation_4(id0,id1,id2,id3); }

  private native int RemoveOperation_5(int id0);
  public int RemoveOperation(int id0)
    { return RemoveOperation_5(id0); }

  private native int RemoveOperation_6(int id0,int id1,int id2,int id3);
  public int RemoveOperation(int id0,int id1,int id2,int id3)
    { return RemoveOperation_6(id0,id1,id2,id3); }

  private native int RemoveOperation_7(int id0,String id1,int id2,int id3);
  public int RemoveOperation(int id0,String id1,int id2,int id3)
    { return RemoveOperation_7(id0,id1,id2,id3); }

  private native int RemoveOperation_8(String id0,String id1,String id2,String id3);
  public int RemoveOperation(String id0,String id1,String id2,String id3)
    { return RemoveOperation_8(id0,id1,id2,id3); }

  private native void RemoveAllOperations_9();
  public void RemoveAllOperations()
    { RemoveAllOperations_9(); }

  public vtkRearrangeFields() { super(); }

  public vtkRearrangeFields(long id) { super(id); }
  public native long   VTKInit();

}
